@@ -86,7 +86,8 @@ class SimpleConsumer:
         clientTimeout = self.consumerConfig.get_client_timeout()
         getMessageRequest.timeoutTimestamp = (Utils.current_time_mills() + clientTimeout)
 
-        getMessageResponse = GetMessageResponse(messageBlocks=[])
+        getMessageResponse = GetMessageResponse()
+        getMessageResponse.messageBlocks = []
         try:
             getMessageResponse = self.scheduleInfoCache.get_or_create_message_client(
                 topicAndPartition=self.topicAndPartition).get_message(getMessageRequest)
