@@ -52,12 +52,6 @@ class TalosProducerConfigKeys(TalosClientConfigKeys):
     GALAXY_TALOS_PRODUCER_MAX_PUT_MESSAGE_BYTES_MINIMUM = 1
     GALAXY_TALOS_PRODUCER_MAX_PUT_MESSAGE_BYTES_MAXIMUM = 10 * 1024 * 1024
 
-    # The producer max bytes of a single message
-    GALAXY_TALOS_PRODUCER_MAX_SINGLE_MESSAGE_BYTES = "galaxy.talos.producer.max.single.message.bytes"
-    GALAXY_TALOS_PRODUCER_MAX_SINGLE_MESSAGE_BYTES_DEFAULT = 10 * 1024 * 1024
-    GALAXY_TALOS_PRODUCER_MAX_SINGLE_MESSAGE_BYTES_MINIMUM = 10 * 1024 * 1024
-    GALAXY_TALOS_PRODUCER_MAX_SINGLE_MESSAGE_BYTES_MAXIMUM = 20 * 1024 * 1024
-
     # The producer thread pool number
     GALAXY_TALOS_PRODUCER_THREAD_POOL_SIZE = "galaxy.talos.producer.thread.pool.size"
     GALAXY_TALOS_PRODUCER_THREAD_POOL_SIZE_DEFAULT = 16
@@ -87,4 +81,4 @@ class TalosProducerConfigKeys(TalosClientConfigKeys):
     # The producer compression type, right now suport "NONE", "SNAPPY" and "GZIP";
     # default is "SNAPPY";
     GALAXY_TALOS_PRODUCER_COMPRESSION_TYPE = "galaxy.talos.producer.compression.type"
-    GALAXY_TALOS_PRODUCER_COMPRESSION_TYPE_DEFAULT = "SNAPPY"
\ No newline at end of file
+    GALAXY_TALOS_PRODUCER_COMPRESSION_TYPE_DEFAULT = "SNAPPY"
